==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/hu_HU.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG modul';
$lang['uninstalled'] = 'A modul elt&aacute;vol&iacute;t&aacute;sa megt&ouml;rt&eacute;nt.';
$lang['installed'] = 'A modulb&oacute;l a(z) %s verzi&oacute; van telep&iacute;tve.';
$lang['stripbackgroundtags'] = 'Background Tag-ok kiv&eacute;tele a CSS-ből';
$lang['source_formatting_text'] = 'Forr&aacute;sform&aacute;z&aacute;s alkalmaz&aacute;sa a kimeneti HTML-en';
$lang['dropdownblockformats_text'] = 'Block form&aacute;tumok a leny&iacute;l&oacute; men&uuml;kben';
$lang['allowtables'] = 'T&aacute;bl&aacute;zat műveletek enged&eacute;lyez&eacute;se';
$lang['newlinestyle_text'] = '&Uacute;jsor st&iacute;lus';
$lang['pstyle'] = '<p> st&iacute;lus';
$lang['brstyle'] = '<br /> st&iacute;lus';
$lang['usecompressiontext'] = 'A gz t&ouml;m&ouml;r&iacute;t&eacute;s haszn&aacute;lata';
$lang['usecompressionhelp'] = 'Ez meggyors&iacute;thatja a TineMCE bet&ouml;lt&eacute;s&eacute;t, de meg is akad&aacute;lyozhatja a műk&ouml;d&eacute;s&eacute;t bizonyos rendszereken. K&ouml;r&uuml;ltekint&eacute;ssel haszn&aacute;ld.';
$lang['forcedrootblocktext'] = '<p> alapblokk haszn&aacute;lat&aacute;nak kik&eacute;nyszer&iacute;t&eacute;se';
$lang['forcedrootblockhelp'] = 'Kik&eacute;nyszer&iacute;ti, hogy a tartalom legal&aacute;bb <p>-tagok k&ouml;z&eacute; legyen z&aacute;rva';
$lang['filepickerstyle'] = 'F&aacute;jlv&aacute;laszt&oacute; st&iacute;lusa';
$lang['filepickersize'] = 'F&aacute;jlv&aacute;laszt&oacute; m&eacute;rete';
$lang['allowuploadtext'] = 'Allow upload and creating dirs in FilePicker';
$lang['cannotreadconfig'] = 'Cannot read the file tinyconfig.php directly so TinyMCE will probably not work. You should check the permissions of the file and of the parent dirs, which should be readable for all but only writable for owner.';
$lang['filenameonly'] = 'F&aacute;jlnevek mutat&aacute;sa';
$lang['thumbnailsonly'] = 'Miniatűr&ouml;k mutat&aacute;sa';
$lang['filenameandthumbnails'] = 'F&aacute;jlnevek &eacute;s miniatűr&ouml;k mutat&aacute;sa';
$lang['skinstext'] = 'Skin';
$lang['skinvariationtext'] = 'Skin vari&aacute;ci&oacute;';
$lang['advancedwarning'] = '<strong>Please note!<br/>Changing these settings can cause TinyMCE to stop working or the generated code to be wrong in some way. Only edit this if you know what you are doing! Please consult the TinyMCE website before playing with this.</strong>';
$lang['entityencoding_text'] = 'Elemek k&oacute;dol&aacute;sa';
$lang['rawencoding'] = 'Egyszerű k&oacute;dol&aacute;s (a leggyorsabb, a legt&ouml;b esetben műk&ouml;dik)';
$lang['namedencoding'] = 'N&eacute;v alap&uacute; k&oacute;dol&aacute;s (pl. mint &nbsp;)';
$lang['numericencoding'] = 'Numerikus k&oacute;dol&aacute;s (pl. mint &amp;#160;)';
$lang['show_path_text'] = 'Az elem &uacute;tvonal&aacute;nak mutat&aacute;sa a szerkesztő fel&uuml;let alj&aacute;n.';
$lang['toolbar_tab'] = 'Eszk&ouml;zt&aacute;r';
$lang['toolbar_help'] = 'Ezek az opci&oacute;k egy vesszővel elv&aacute;lasztott list&aacute;ban tartalmazz&aacute;k az eszk&ouml;zt&aacute;ron haszn&aacute;lni k&iacute;v&aacute;nt gombok/vez&eacute;rlő elemek nev&eacute;t.';
$lang['toolbar_text'] = 'Eszk&ouml;zt&aacute;r';
$lang['toolbarhelptext'] = 'Kattints ide a TinyMCE-wiki megtekint&eacute;s&eacute;hez, tov&aacute;bbi eszk&ouml;zt&aacute;r-instrukci&oacute;khoz.';
$lang['editor_width_text'] = 'A szerkesztő mező sz&eacute;less&eacute;ge';
$lang['editor_height_text'] = 'A szerkesztő mező magass&aacute;ga';
$lang['auto'] = 'Automatikus';
$lang['or'] = 'vagy';
$lang['datetimeformat_text'] = 'D&aacute;tum/idő form&aacute;tum';
$lang['timetext'] = 'Idő';
$lang['datetext'] = 'D&aacute;tum';
$lang['datetimeformat_help'] = 'Kattints ide a form&aacute;tum s&uacute;g&oacute;hoz';
$lang['extraconfigtext'] = 'Extra be&aacute;ll&iacute;t&aacute;s';
$lang['extraconfighelp'] = 'TinyMCE-wiki megtekint&eacute;se tov&aacute;bbi instrukci&oacute;khoz';
$lang['customdropdowntext'] = 'Egyedi leg&ouml;rd&uuml;lő lista';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup enabled';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Load the CMS-linker';
$lang['loadcmslinkerhelp'] = 'This generates the javascript-code needed to allow &#039;cmslinker&#039; to be added to a toolbar.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-style';
$lang['cmsselflinkstyle'] = '{cms_selflink}-style';
$lang['ahrefstyle'] = '<a href>-style';
$lang['relativeurlstext'] = 'Generate relative urls';
$lang['forcecleanpastetext'] = 'Force clean on paste';
$lang['forcecleanpastehelp'] = 'This should be enabled to remove strange formatting codes when pasting from Word etc.';
$lang['bodycss_text'] = 'Body tag CSS';
$lang['bodycss_help'] = 'hagyd &#039;BLANK&#039;-on vagy &aacute;ll&iacute;tsd &#039;DEFAULT&#039;-ra az oldal alap&eacute;rtelmezett st&iacute;lus&aacute;nak (&#039;PAGE CSS&#039;) haszn&aacute;lat&aacute;hoz';
$lang['includeonlyscreencss_text'] = 'Include only screen CSS';
$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Use static config file';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'A WYSIWYG ki-/bekapcsol&aacute;sa gomb mutat&aacute;sa';
$lang['togglewysiwyg'] = 'WYSIWYG ki-/bekapcsol&aacute;sa';
$lang['styles_tab'] = 'CSS St&iacute;lusok';
$lang['styles_help'] = 'Ha ezt a mezőt &uuml;resen hagyod, akkor a TinyMCE feldolgozza a CSS file-t &eacute;s kilist&aacute;zza a st&iacute;lusokat a felhaszn&aacute;l&oacute;nak. Ha csak bizonyosakat akarsz megmutatni, add meg őket &quot;Style 1=stlye1; Style 2=stlye2&quot; form&aacute;ban az al&aacute;bbi mezőben. A marad&eacute;k mezőkben megadhatod a CSS st&iacute;lust t&aacute;bl&aacute;zatok, sorok &eacute;s cell&aacute;k sz&aacute;m&aacute;ra. &Uuml;res mező eset&eacute;n az &aacute;ltal&aacute;nos st&iacute;lusb&oacute;l &ouml;r&ouml;k&ouml;lt st&iacute;lusok lesznek haszn&aacute;lva.';
$lang['css_styles_text'] = '&Aacute;ltal&aacute;nos';
$lang['accessdenied'] = 'A hozz&aacute;f&eacute;r&eacute;s megtagadva. K&eacute;rem, ellenőrizze a jogosults&aacute;gokat.';
$lang['error'] = 'Hiba!';
$lang['submit'] = 'Elk&uuml;ld';
$lang['update'] = 'Friss&iacute;t&eacute;s';
$lang['settings'] = 'Be&aacute;ll&iacute;t&aacute;sok';
$lang['settingssaved'] = 'A be&aacute;ll&iacute;t&aacute;sokat mentett&uuml;k';
$lang['advancedsaved'] = 'Halad&oacute; be&aacute;ll&iacute;t&aacute;sokat mentett&uuml;k';
$lang['toolbarsaved'] = 'Az eszk&ouml;zt&aacute;rat mentett&uuml;k';
$lang['stylessaved'] = 'A st&iacute;lusokat mentett&uuml;k';
$lang['testareatext'] = 'Teszt ter&uuml;let, a tartalmat nem fogja b&aacute;ntani, ha itt pr&oacute;b&aacute;lkozol...';
$lang['reset'] = 'Az alap&eacute;rtelmezett &eacute;rt&eacute;kek vissza&aacute;ll&iacute;t&aacute;sa';
$lang['resetall'] = 'Minden be&aacute;lll&iacute;t&aacute;s vissza&aacute;ll&iacute;t&aacute;sa alap&eacute;rtelmezettre';
$lang['confirmreset'] = 'Are you sure you want to reset these settings to their defaults?';
$lang['confirmresetall'] = 'Are you sure you want to reset ALL settings to their defaults?';
$lang['settingsreset'] = 'These settings was reset to default';
$lang['allsettingsreset'] = 'All settings was reset to default';
$lang['upgraded'] = 'has been upgraded to version %s';
$lang['customdropdown'] = 'Custom dropdown-menu';
$lang['cmsmslinker'] = 'Insert link to cmsms-page';
$lang['backend_toolbars'] = 'Backend toolbar settings';
$lang['frontend_toolbars'] = 'Frontend toolbar settings';
$lang['plugins_tab'] = 'Plugins';
$lang['plugins_help'] = 'Choose the plugins you want to activate. Documentation can be found <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">here</a>';
$lang['plugins_text'] = 'Plugins';
$lang['saveplugins'] = 'Save plugins';
$lang['pluginssaved'] = 'Plugins saved';
$lang['youareintext'] = 'You are in';
$lang['extrastylestext'] = 'Additions to stylesheet';
$lang['extrastyleshelp'] = 'CSS entered here will be added to the stylesheet read by TinyMCE after it recieves the CMSms styles';
$lang['uploadnewfile'] = 'New file';
$lang['uploadfile'] = 'Upload';
$lang['createnewdir'] = 'New dir';
$lang['createdir'] = 'Create';
$lang['nodirname'] = 'No dirname provided';
$lang['direxists'] = 'Dirname already exists';
$lang['newdircreated'] = 'New dir successfully created';
$lang['newdirfailed'] = 'An error occured trying to create dir';
$lang['nofile'] = 'No file was uploaded';
$lang['filetoobig'] = 'Uploaded file is too big';
$lang['uploadfailed'] = 'Error moving uploaded file into place';
$lang['fileuploaded'] = 'File successfully uploaded';
$lang['filepickertitle'] = 'CMSMadeSimple File Selection';
$lang['success'] = 'Success';
$lang['fileoperations'] = 'File operations';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Size';
$lang['dimensions'] = 'WxH';
$lang['advanced_tab'] = 'Advanced';
$lang['help'] = '	<h3>Ez mit eredm&eacute;nyez?</h3>
	<p>Lehetőv&eacute; teszi, hogy a TinyMCE-t haszn&aacute;ld WYSIWYG szerkesztők&eacute;nt.</p>
	<h3>Hogyan haszn&aacute;lhatom?</h3>
	<p>Telep&iacute;tsd, majd a Felhaszn&aacute;l&oacute;i Preferenci&aacute;k k&ouml;z&ouml;tt v&aacute;laszd wysiwyg szerkesztőnek.</p>';
$lang['utma'] = '156861353.1745742775.1167462096.1227524728.1227528035.121';
$lang['utmz'] = '156861353.1223837548.118.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/TinyMCE/lang/ext/hu_HU.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG modul';
$lang['uninstalled'] = 'A modul elt&aacute;vol&iacute;t&aacute;sa megt&ouml;rt&eacute;nt.';
$lang['installed'] = 'A modulb&oacute;l a(z) %s verzi&oacute; van telep&iacute;tve.';
$lang['stripbackgroundtags'] = 'Background Tag-ok kiv&eacute;tele a CSS-ből';
$lang['source_formatting_text'] = 'Forr&aacute;sform&aacute;z&aacute;s alkalmaz&aacute;sa a kimeneti HTML-en';
$lang['dropdownblockformats_text'] = 'Block form&aacute;tumok a leny&iacute;l&oacute; men&uuml;kben';
$lang['allowtables'] = 'T&aacute;bl&aacute;zat műveletek enged&eacute;lyez&eacute;se';
$lang['newlinestyle_text'] = '&Uacute;jsor st&iacute;lus';
$lang['pstyle'] = '<p> st&iacute;lus';
$lang['brstyle'] = '<br /> st&iacute;lus';
$lang['usecompressiontext'] = 'A gz t&ouml;m&ouml;r&iacute;t&eacute;s haszn&aacute;lata';
$lang['usecompressionhelp'] = 'Ez meggyors&iacute;thatja a TineMCE bet&ouml;lt&eacute;s&eacute;t, de meg is akad&aacute;lyozhatja a műk&ouml;d&eacute;s&eacute;t bizonyos rendszereken. K&ouml;r&uuml;ltekint&eacute;ssel haszn&aacute;ld.';
$lang['forcedrootblocktext'] = '<p> alapblokk haszn&aacute;lat&aacute;nak kik&eacute;nyszer&iacute;t&eacute;se';
$lang['forcedrootblockhelp'] = 'Kik&eacute;nyszer&iacute;ti, hogy a tartalom legal&aacute;bb <p>-tagok k&ouml;z&eacute; legyen z&aacute;rva';
$lang['filepickerstyle'] = 'F&aacute;jlv&aacute;laszt&oacute; st&iacute;lusa';
$lang['filepickersize'] = 'F&aacute;jlv&aacute;laszt&oacute; m&eacute;rete';
$lang['allowuploadtext'] = 'Allow upload and creating dirs in FilePicker';
$lang['cannotreadconfig'] = 'Cannot read the file tinyconfig.php directly so TinyMCE will probably not work. You should check the permissions of the file and of the parent dirs, which should be readable for all but only writable for owner.';
$lang['filenameonly'] = 'F&aacute;jlnevek mutat&aacute;sa';
$lang['thumbnailsonly'] = 'Miniatűr&ouml;k mutat&aacute;sa';
$lang['filenameandthumbnails'] = 'F&aacute;jlnevek &eacute;s miniatűr&ouml;k mutat&aacute;sa';
$lang['skinstext'] = 'Skin';
$lang['skinvariationtext'] = 'Skin vari&aacute;ci&oacute;';
$lang['advancedwarning'] = '<strong>Please note!<br/>Changing these settings can cause TinyMCE to stop working or the generated code to be wrong in some way. Only edit this if you know what you are doing! Please consult the TinyMCE website before playing with this.</strong>';
$lang['entityencoding_text'] = 'Elemek k&oacute;dol&aacute;sa';
$lang['rawencoding'] = 'Egyszerű k&oacute;dol&aacute;s (a leggyorsabb, a legt&ouml;b esetben műk&ouml;dik)';
$lang['namedencoding'] = 'N&eacute;v alap&uacute; k&oacute;dol&aacute;s (pl. mint &nbsp;)';
$lang['numericencoding'] = 'Numerikus k&oacute;dol&aacute;s (pl. mint &amp;#160;)';
$lang['show_path_text'] = 'Az elem &uacute;tvonal&aacute;nak mutat&aacute;sa a szerkesztő fel&uuml;let alj&aacute;n.';
$lang['toolbar_tab'] = 'Eszk&ouml;zt&aacute;r';
$lang['toolbar_help'] = 'Ezek az opci&oacute;k egy vesszővel elv&aacute;lasztott list&aacute;ban tartalmazz&aacute;k az eszk&ouml;zt&aacute;ron haszn&aacute;lni k&iacute;v&aacute;nt gombok/vez&eacute;rlő elemek nev&eacute;t.';
$lang['toolbar_text'] = 'Eszk&ouml;zt&aacute;r';
$lang['toolbarhelptext'] = 'Kattints ide a TinyMCE-wiki megtekint&eacute;s&eacute;hez, tov&aacute;bbi eszk&ouml;zt&aacute;r-instrukci&oacute;khoz.';
$lang['editor_width_text'] = 'A szerkesztő mező sz&eacute;less&eacute;ge';
$lang['editor_height_text'] = 'A szerkesztő mező magass&aacute;ga';
$lang['auto'] = 'Automatikus';
$lang['or'] = 'vagy';
$lang['datetimeformat_text'] = 'D&aacute;tum/idő form&aacute;tum';
$lang['timetext'] = 'Idő';
$lang['datetext'] = 'D&aacute;tum';
$lang['datetimeformat_help'] = 'Kattints ide a form&aacute;tum s&uacute;g&oacute;hoz';
$lang['extraconfigtext'] = 'Extra be&aacute;ll&iacute;t&aacute;s';
$lang['extraconfighelp'] = 'TinyMCE-wiki megtekint&eacute;se tov&aacute;bbi instrukci&oacute;khoz';
$lang['customdropdowntext'] = 'Egyedi leg&ouml;rd&uuml;lő lista';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup enabled';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Load the CMS-linker';
$lang['loadcmslinkerhelp'] = 'This generates the javascript-code needed to allow &#039;cmslinker&#039; to be added to a toolbar.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-style';
$lang['cmsselflinkstyle'] = '{cms_selflink}-style';
$lang['ahrefstyle'] = '<a href>-style';
$lang['relativeurlstext'] = 'Generate relative urls';
$lang['forcecleanpastetext'] = 'Force clean on paste';
$lang['forcecleanpastehelp'] = 'This should be enabled to remove strange formatting codes when pasting from Word etc.';
$lang['bodycss_text'] = 'Body tag CSS';
$lang['bodycss_help'] = 'hagyd &#039;BLANK&#039;-on vagy &aacute;ll&iacute;tsd &#039;DEFAULT&#039;-ra az oldal alap&eacute;rtelmezett st&iacute;lus&aacute;nak (&#039;PAGE CSS&#039;) haszn&aacute;lat&aacute;hoz';
$lang['includeonlyscreencss_text'] = 'Include only screen CSS';
$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Use static config file';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'A WYSIWYG ki-/bekapcsol&aacute;sa gomb mutat&aacute;sa';
$lang['togglewysiwyg'] = 'WYSIWYG ki-/bekapcsol&aacute;sa';
$lang['styles_tab'] = 'CSS St&iacute;lusok';
$lang['styles_help'] = 'Ha ezt a mezőt &uuml;resen hagyod, akkor a TinyMCE feldolgozza a CSS file-t &eacute;s kilist&aacute;zza a st&iacute;lusokat a felhaszn&aacute;l&oacute;nak. Ha csak bizonyosakat akarsz megmutatni, add meg őket &quot;Style 1=stlye1; Style 2=stlye2&quot; form&aacute;ban az al&aacute;bbi mezőben. A marad&eacute;k mezőkben megadhatod a CSS st&iacute;lust t&aacute;bl&aacute;zatok, sorok &eacute;s cell&aacute;k sz&aacute;m&aacute;ra. &Uuml;res mező eset&eacute;n az &aacute;ltal&aacute;nos st&iacute;lusb&oacute;l &ouml;r&ouml;k&ouml;lt st&iacute;lusok lesznek haszn&aacute;lva.';
$lang['css_styles_text'] = '&Aacute;ltal&aacute;nos';
$lang['accessdenied'] = 'A hozz&aacute;f&eacute;r&eacute;s megtagadva. K&eacute;rem, ellenőrizze a jogosults&aacute;gokat.';
$lang['error'] = 'Hiba!';
$lang['submit'] = 'Elk&uuml;ld';
$lang['update'] = 'Friss&iacute;t&eacute;s';
$lang['settings'] = 'Be&aacute;ll&iacute;t&aacute;sok';
$lang['settingssaved'] = 'A be&aacute;ll&iacute;t&aacute;sokat mentett&uuml;k';
$lang['advancedsaved'] = 'Halad&oacute; be&aacute;ll&iacute;t&aacute;sokat mentett&uuml;k';
$lang['toolbarsaved'] = 'Az eszk&ouml;zt&aacute;rat mentett&uuml;k';
$lang['stylessaved'] = 'A st&iacute;lusokat mentett&uuml;k';
$lang['testareatext'] = '<p>Teszt ter&uuml;let, a tartalmat nem fogja b&aacute;ntani, ha itt pr&oacute;b&aacute;lkozol...</p>';
$lang['reset'] = 'Az alap&eacute;rtelmezett &eacute;rt&eacute;kek vissza&aacute;ll&iacute;t&aacute;sa';
$lang['resetall'] = 'Minden be&aacute;lll&iacute;t&aacute;s vissza&aacute;ll&iacute;t&aacute;sa alap&eacute;rtelmezettre';
$lang['confirmreset'] = 'Are you sure you want to reset these settings to their defaults?';
$lang['confirmresetall'] = 'Are you sure you want to reset ALL settings to their defaults?';
$lang['settingsreset'] = 'These settings was reset to default';
$lang['allsettingsreset'] = 'All settings was reset to default';
$lang['upgraded'] = 'has been upgraded to version %s';
$lang['customdropdown'] = 'Custom dropdown-menu';
$lang['cmsmslinker'] = 'Insert link to cmsms-page';
$lang['backend_toolbars'] = 'Backend toolbar settings';
$lang['frontend_toolbars'] = 'Frontend toolbar settings';
$lang['plugins_tab'] = 'Plugins';
$lang['plugins_help'] = 'Choose the plugins you want to activate. Documentation can be found <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">here</a>';
$lang['plugins_text'] = 'Plugins';
$lang['saveplugins'] = 'Save plugins';
$lang['pluginssaved'] = 'Plugins saved';
$lang['youareintext'] = 'You are in';
$lang['extrastylestext'] = 'Additions to stylesheet';
$lang['extrastyleshelp'] = 'CSS entered here will be added to the stylesheet read by TinyMCE after it recieves the CMSms styles';
$lang['uploadnewfile'] = 'New file';
$lang['uploadfile'] = 'Upload';
$lang['createnewdir'] = 'New dir';
$lang['createdir'] = 'Create';
$lang['nodirname'] = 'No dirname provided';
$lang['direxists'] = 'Dirname already exists';
$lang['newdircreated'] = 'New dir successfully created';
$lang['newdirfailed'] = 'An error occured trying to create dir';
$lang['nofile'] = 'No file was uploaded';
$lang['filetoobig'] = 'Uploaded file is too big';
$lang['uploadfailed'] = 'Error moving uploaded file into place';
$lang['fileuploaded'] = 'File successfully uploaded';
$lang['filepickertitle'] = 'CMSMadeSimple File Selection';
$lang['success'] = 'Success';
$lang['fileoperations'] = 'File operations';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Size';
$lang['dimensions'] = 'WxH';
$lang['advanced_tab'] = 'Advanced';
$lang['help'] = '	<h3>Ez mit eredm&eacute;nyez?</h3>
	<p>Lehetőv&eacute; teszi, hogy a TinyMCE-t haszn&aacute;ld WYSIWYG szerkesztők&eacute;nt.</p>
	<h3>Hogyan haszn&aacute;lhatom?</h3>
	<p>Telep&iacute;tsd, majd a Felhaszn&aacute;l&oacute;i Preferenci&aacute;k k&ouml;z&ouml;tt v&aacute;laszd wysiwyg szerkesztőnek.</p>';
$lang['utma'] = '156861353.1745742775.1167462096.1227524728.1227528035.121';
$lang['utmz'] = '156861353.1223837548.118.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
